@@ -31,7 +31,7 @@ Usage::
     get_transit_gateway_registrations_paginator: GetTransitGatewayRegistrationsPaginator = client.get_paginator("get_transit_gateway_registrations")
     ```
 """
-from mypy_boto3_networkmanager.client import NetworkManagerClient as Client, NetworkManagerClient
+from mypy_boto3_networkmanager.client import NetworkManagerClient, NetworkManagerClient as Client
 from mypy_boto3_networkmanager.paginator import (
     DescribeGlobalNetworksPaginator,
     GetCustomerGatewayAssociationsPaginator,
